@@ -1,6 +1,6 @@
-g.calibrate = function(datafile,use.temp=TRUE,spherecrit=0.3,minloadcrit=72,printsummary=TRUE,
+g.calibrate = function(datafile, spherecrit=0.3,minloadcrit=72,printsummary=TRUE,
                        chunksize=c(),windowsizes=c(5,900,3600),selectdaysfile=c(),dayborder=0,
-                       desiredtz = c(), ...) {
+                       desiredtz = "", ...) {
   #get input variables
   input = list(...)
   if (length(input) > 0) {
@@ -41,10 +41,12 @@ g.calibrate = function(datafile,use.temp=TRUE,spherecrit=0.3,minloadcrit=72,prin
   if (length(chunksize) == 0) chunksize = 1
   if (chunksize > 1) chunksize = 1
   if (chunksize < 0.4) chunksize = 0.4
+  use.temp = TRUE
   filename = unlist(strsplit(as.character(datafile),"/"))
   filename = filename[length(filename)]
   # set parameters
-  filequality = data.frame(filetooshort=FALSE,filecorrupt=FALSE,filedoesnotholdday = FALSE)
+  filequality = data.frame(filetooshort=FALSE,filecorrupt=FALSE,
+                           filedoesnotholdday = FALSE, stringsAsFactors = TRUE)
   ws4 = 10 #epoch for recalibration, don't change
   ws2 = windowsizes[2] #dummy variable
   ws =  windowsizes[3] # window size for assessing non-wear time (seconds)
@@ -120,7 +122,7 @@ g.calibrate = function(datafile,use.temp=TRUE,spherecrit=0.3,minloadcrit=72,prin
   while (LD > 1) {
     P = c()
     if (i  == 1) {
-      cat(paste("\nLoading block: ",i,sep=""))
+      cat(paste("\nLoading chunk: ",i,sep=""))
     } else {
       cat(paste(" ",i,sep=""))
     }
@@ -168,7 +170,13 @@ g.calibrate = function(datafile,use.temp=TRUE,spherecrit=0.3,minloadcrit=72,prin
       } else if (dformat == 2) {
         data = as.matrix(P)
       } else if (dformat == 4) {
-        data = P$data
+        if (P$header$hardwareType == "AX6") { # cwa AX6
+          # Note 18-Feb-2020: For the moment GGIR ignores the AX6 gyroscope signals until robust sensor
+          # fusion algorithms and gyroscope metrics have been prepared
+          data = P$data[,-c(2:4)]
+        } else { # cwa AX3
+          data = P$data
+        }
       } else if (dformat == 5) {
         data = P$data
       }
@@ -176,6 +184,7 @@ g.calibrate = function(datafile,use.temp=TRUE,spherecrit=0.3,minloadcrit=72,prin
       if (min(dim(S)) > 1) {
         data = rbind(S,data)
       }
+      
       LD = nrow(data)
       #store data that could not be used for this block, but will be added to next block
       use = (floor(LD / (ws*sf))) * (ws*sf) #number of datapoint to use
@@ -457,7 +466,7 @@ g.calibrate = function(datafile,use.temp=TRUE,spherecrit=0.3,minloadcrit=72,prin
     }
   }
   if (length(ncol(meta_temp)) != 0) {
-    spheredata = data.frame(A = meta_temp)
+    spheredata = data.frame(A = meta_temp, stringsAsFactors = TRUE)
     if (use.temp == TRUE) {
       names(spheredata) = c("Euclidean Norm","meanx","meany","meanz","sdx","sdy","sdz","temperature")
     } else {
