@@ -1,5 +1,5 @@
-g.cwaread = function(fileName, start = 0, end = 0, progressBar = FALSE, desiredtz = c(), configtz = c()) {
-
+g.cwaread = function(fileName, start = 0, end = 0, progressBar = FALSE, desiredtz = "", configtz = c()) {
+  
   if (length(configtz) == 0) configtz = desiredtz
   # Credits: The code in this function was contributed by Dr. Evgeny Mirkes (Leicester University, UK)
   #========================================================================
@@ -40,8 +40,10 @@ g.cwaread = function(fileName, start = 0, end = 0, progressBar = FALSE, desiredt
   #       battery is battery charge for the block
   #       light is light sensor measurement for the block
   #
-
-  #############################################################################
+  # Background info on data format:
+  # https://github.com/digitalinteraction/openmovement/blob/master/Docs/ax3/ax3-technical.md
+    #############################################################################
+  
   # Internal functions
   timestampDecoder = function(coded, fraction, shift) {
     year = struc[[1]]
@@ -56,7 +58,7 @@ g.cwaread = function(fileName, start = 0, end = 0, progressBar = FALSE, desiredt
       # Form string representation of date and convert it to number
       year = as.numeric(as.POSIXct(
         paste0(year, "-", month, "-", day, " ", hours, ":", mins, ":", secs),
-      tz=configtz))
+        tz=configtz))
     }
     else{
       secs = bitwAnd(coded, 0x3fL)
@@ -69,7 +71,7 @@ g.cwaread = function(fileName, start = 0, end = 0, progressBar = FALSE, desiredt
     # Add fractional part and shift
     return(year + fraction / 65536 + shift)
   }
-
+  
   readHeader = function(fid, numDBlocks) {
     # fid is file identifier
     # numDBlocks is number of data blocks
@@ -86,24 +88,37 @@ g.cwaread = function(fileName, start = 0, end = 0, progressBar = FALSE, desiredt
     #   blocks is number of datablocks with 80 or 120 observations in each
     #       Unfortunately frequency of measurement is varied in this device.
     #
-
+    
     # Start from the file origin
     seek(fid,0)
-    # Read block header and check correcness of name
-    idstr = readChar(fid,2,useBytes = TRUE)
+    # Read block header and check correctness of name
+    idstr = suppressWarnings(readChar(fid,2,useBytes = TRUE)) #offset 0 1
     if (idstr == "MD") {
       # It is correct header block read information from it
-      # skip 3 bytes
-      readChar(fid,3,useBytes = TRUE)
-      uniqueSerialCode = readBin(fid, integer(), size = 2, signed = FALSE)
-      # skip 29 bytes and read 36th byte as frequency of measurement
-      readChar(fid, 29, useBytes = TRUE)
-      frequency = round( 3200 / bitwShiftL(1, 15 - bitwAnd(readBin(fid, integer(), size = 1), 15)))
-      # skip 5 bytes and read 41th byte as firmware version
-      readChar(fid, 4, useBytes = TRUE)
-      version = readBin(fid, integer(), size = 1)
-      # Skip 983 bytes and go to the first data block
-      readChar(fid, 982, useBytes = TRUE)
+      readChar(fid,2,useBytes = TRUE) #offset 2 3
+      # hardware type: AX6 or AX3
+      hwType = readBin(fid, raw(), size = 1) #offset 4
+      if (hwType == "64") {
+        hardwareType = "AX6"
+      } else {
+        hardwareType = "AX3" 
+      }
+      # session id and device id
+      lowerDeviceId = readBin(fid, integer(), size = 2, signed = FALSE) #offset 5 6
+      sessionID = readBin(fid, integer(), size = 4) #offset 7 8 9 10
+      upperDeviceId = readBin(fid, integer(), size = 2, signed = FALSE) #offset 11 12
+      if (upperDeviceId >= 65535) upperDeviceId = 0
+      uniqueSerialCode = upperDeviceId * 65536 + lowerDeviceId
+      suppressWarnings(readChar(fid, 23, useBytes = TRUE)) #offset 13..34
+      # sensorConfig = readBin(fid, raw(), size = 1) #offset 35
+      # sample rate and dynamic range accelerometer
+      samplerate_dynrange = readBin(fid, integer(), size = 1) #offset 36
+      frequency = round( 3200 / bitwShiftL(1, 15 - bitwAnd(samplerate_dynrange, 15)))
+      accrange = bitwShiftR(16,(bitwShiftR(samplerate_dynrange,6)))
+      suppressWarnings(readChar(fid, 4, useBytes = TRUE)) #offset 37..40
+      version = readBin(fid, integer(), size = 1) #offset 41
+      # Skip 982 bytes and go to the first data block
+      suppressWarnings(readChar(fid, 982, useBytes = TRUE)) #offset 42..1024
       # Read the first data block without data
       datas = readDataBlock(fid, complete = FALSE)
       if (is.null(datas)){
@@ -118,15 +133,18 @@ g.cwaread = function(fileName, start = 0, end = 0, progressBar = FALSE, desiredt
     }
     # start = as.POSIXct(datas$start, origin = "1970-01-01", tz=configtz)
     start = as.POSIXct(datas$start, origin = "1970-01-01", tz=desiredtz)
+    
+    returnobject = list(
+      uniqueSerialCode = uniqueSerialCode, frequency = frequency,
+      start = start,
+      device = "Axivity", firmwareVersion = version, blocks = numDBlocks,
+      accrange = accrange, hardwareType=hardwareType
+    )
     return(invisible(
-      list(
-        uniqueSerialCode = uniqueSerialCode, frequency = frequency,
-        start = start,
-        device = "Axivity", firmwareVersion = version, blocks = numDBlocks
-      )
+      returnobject
     ))
   }
-
+  
   unsigned8 = function(x) {
     # Auxiliary function for normalisation of unsigned integers
     if (x < 0)
@@ -134,7 +152,49 @@ g.cwaread = function(fileName, start = 0, end = 0, progressBar = FALSE, desiredt
     else
       return(x)
   }
-
+  unsigned16 = function(x) {
+    # Auxiliary function for normalisation of unsigned integers
+    if (x < 0)
+      return(x + 65536) #2^16
+    else
+      return(x)
+  }
+  
+  # numUnpack2 = function(packedData) {
+  #   #---------------------------------
+  #   # Code for unpacking provided by Dan Jackson:
+  #   #---------------------------------
+  #   count = length(packedData)
+  #   xyz = integer(count * 3)
+  #   for (i in 1:count) {
+  #     # eezzzzzz zzzzyyyy yyyyyyxx xxxxxxxx
+  #     value = packedData[i]
+  # 
+  #     # Isolate each axis component
+  #     x = bitwAnd(           value     , 0x03ff)
+  #     y = bitwAnd(bitwShiftR(value, 10), 0x03ff)
+  #     z = bitwAnd(bitwShiftR(value, 20), 0x03ff)
+  # 
+  #     # Signed
+  #     if (x >= 0x200) { x = x - 0x400 }
+  #     if (y >= 0x200) { y = y - 0x400 }
+  #     if (z >= 0x200) { z = z - 0x400 }
+  # 
+  #     # Scale
+  #     shift = bitwAnd(bitwShiftR(value, 30), 0x03)
+  #     x = bitwShiftL(x, shift)
+  #     y = bitwShiftL(y, shift)
+  #     z = bitwShiftL(z, shift)
+  # 
+  #     # Store
+  #     xyz[(i - 1) * 3 + 1] = x
+  #     xyz[(i - 1) * 3 + 2] = y
+  #     xyz[(i - 1) * 3 + 3] = z
+  #   }
+  #   data = matrix(xyz, ncol=3, byrow=T)
+  #   return(data)
+  # }
+  
   readDataBlock = function(fid, complete = TRUE){
     # Read one block of data and return list with following elements
     #   frequency is frequency recorded in this block
@@ -148,47 +208,60 @@ g.cwaread = function(fileName, start = 0, end = 0, progressBar = FALSE, desiredt
     #   data is matrix with three columns "x", "y", and "z"
     #   matrix data is presented if complete == TRUE only.
     #
-
+    
     # Check the block header
-    idstr = readChar(fid,2,useBytes = TRUE)
+    idstr = suppressWarnings(readChar(fid,2,useBytes = TRUE))
     if (length(idstr) == 0 || idstr != "AX"){
       return(invisible(NULL))
     } else {
       # Read the data block. Extract several data fields
       # offset 4 contains u16 with timestamp offset
-      readChar(fid, 2, useBytes = TRUE)
+      suppressWarnings(readChar(fid, 2, useBytes = TRUE))
       tsOffset = readBin(fid, integer(), size = 2)
       # read data for timestamp u32 in offset 14
-      readChar(fid, 8, useBytes = TRUE)
+      suppressWarnings(readChar(fid, 8, useBytes = TRUE))
       timeStamp = readBin(fid, integer(), size = 4)
       # Get light u16 in offset 18
-      light = 2 ^ (3.0 * (readBin(fid, integer(), size = 2) / 512.0 + 1.0))
+      offset18 = unsigned16(readBin(fid, integer(), size = 2))
+
+      # light = 2 ^ (3.0 * (offset18 / 512.0 + 1.0)) # used for AX3, but this seems to have been incorrect
+      light = bitwAnd(offset18, 0x03ffL) # this seems to match better what is shown in OMGUI
+      accelScaleCode = bitwShiftR(offset18, 13)
+      accelScale = 1 / (2^(8+accelScaleCode)) # abs removed
+      gyroRangeCode = floor(offset18 / 1024) %% 8
+      gyroRange = 8000 / (2^gyroRangeCode)
+
+      
       # Read and recalculate temperature u16 in offset 20
       temperature = (150.0 * readBin(fid, integer(), size = 2) - 20500.0) / 1000.0;
       # Read and recalculate battery charge u8 in offset 23
-      readChar(fid, 1, useBytes = TRUE)
+      suppressWarnings(readChar(fid, 1, useBytes = TRUE))
       battery = 3.0 * (unsigned8(readBin(fid, integer(), size = 1)) / 512.0 + 1.0);
       # sampling rate in one of file format U8 in offset 24
-      frequency = readBin(fid, integer(), size = 1)
+      samplerate_dynrange = readBin(fid, integer(), size = 1)
       # format of data in block u8  in offset 25
-      temp = readBin(fid, integer(), size = 1)
+      # temp = readBin(fid, integer(), size = 1)
+      temp_raw = readBin(fid, raw(), size = 1)
+      Naxes = as.integer(substr(temp_raw,1,1))
+      temp = as.integer(temp_raw)
       packed = bitwAnd(temp,15) == 0
       # can be measurement with whole seconds or sample rate u16 in offset 26
       temp = readBin(fid, integer(), size = 2)
       # number of observations in block U16 in offset 28
-      blockLength = readBin(fid, integer(), size = 2)
+      blockLength = readBin(fid, integer(), size = 2) # blockLength is expected to be 40 for AX6, 80 or 120 for AX3
       # auxiliary variables
       shift = 0
       fractional = 0
       # Consider two possible formats.
       # Very old file have zero in offset 24 and frequency in offset 26
-      if (frequency != 0) {
+      if (samplerate_dynrange != 0) {
         # value in offset 26 is index of measurement with whole number of seconds
         shift = temp
         # If tsOffset is not null then timestamp offset was artificially
         # modified for backwards-compatibility ... therefore undo this...
         if (bitwAnd(tsOffset, 0x8000L) != 0) {
-          frequency = round( 3200 / bitwShiftL(1, 15 - bitwAnd(frequency, 15)))
+          frequency = round( 3200 / bitwShiftL(1, 15 - bitwAnd(samplerate_dynrange, 15)))
+          accrange = bitwShiftR(16,(bitwShiftR(samplerate_dynrange,6)))
           # Need to undo backwards-compatible shim:
           # Take into account how many whole samples the fractional part
           # of timestamp accounts for:
@@ -209,30 +282,39 @@ g.cwaread = function(fileName, start = 0, end = 0, progressBar = FALSE, desiredt
       }
       # Read data if necessary
       if (complete){
-        if (packed){
+        if (packed){ #32 bit
           # Read 4 byte for three measurements
           packedData = readBin(fid, integer(), size = 4, n = blockLength)
           # Unpack data
-
           data = numUnpack(packedData)
+          # data2 = numUnpack2(packedData)
           # Calculate number of bytes to skip
-          temp = 482 - 4 * blockLength
+          temp = 482 -  4 *(Naxes/3)* blockLength
         } else {
           # Read unpacked data
-          xyz = readBin(fid, integer(), size = 2, n = blockLength*3)
-          data = matrix(xyz,ncol=3,byrow=T)
+          xyz = readBin(fid, integer(), size = 2, n = blockLength*Naxes) #*3
+          data = matrix(xyz,ncol=Naxes,byrow=T) #3
           # Calculate number of bytes to skip
-          temp = 482 - 6 * blockLength
+          temp = 482 - (2 * Naxes * blockLength)
         }
         # Skip the rest of block
-        readChar(fid, temp, useBytes = TRUE)
-        # Set names
-        colnames(data)=c("x","y","z")
-        # Normalize accelerations
-        data = data/256
+        suppressWarnings(readChar(fid, temp, useBytes = TRUE))
+        # Set names and Normalize accelerations
+        if (is.na(header$accrange == TRUE)) {
+          header$accrange = 8
+          # header$accrange = 8 # needed for (old) AX3 when used at non-8g setting
+        }
+        if (Naxes == 3) {
+          colnames(data)=c("x","y","z")
+          data[,c("x","y","z")] = data[,c("x","y","z")] * accelScale  #/ 256
+          
+        } else {
+          colnames(data)=c("gx","gy","gz", "x","y","z")
+          data[,c("gx","gy","gz")] = (data[,c("gx","gy","gz")] / 2^15)* gyroRange
+          data[,c("x","y","z")] = data[,c("x","y","z")] * accelScale
+        }
       } else {
-        # skip to the end of block
-        readChar(fid, 482, useBytes = TRUE)
+        suppressWarnings(readChar(fid, 482, useBytes = TRUE))
       }
       l = list(
         frequency = frequency,
@@ -248,10 +330,10 @@ g.cwaread = function(fileName, start = 0, end = 0, progressBar = FALSE, desiredt
       return(invisible(l))
     }
   }
-
+  
   ################################################################################################
   # Main function
-
+  
   # Parse input arguments
   nargin = nargs()
   if (nargin < 1) {
@@ -262,7 +344,7 @@ g.cwaread = function(fileName, start = 0, end = 0, progressBar = FALSE, desiredt
   pageLength = 300
   # Open file
   fid = file(fileName,"rb")
-
+  
   #############################################################################
   # read header
   struc = list(0,0L)
@@ -291,20 +373,24 @@ g.cwaread = function(fileName, start = 0, end = 0, progressBar = FALSE, desiredt
   # reinitiate file and start reading of data and sesrch the beginning of required
   seek(fid,0)
   # skip header
-  readChar(fid,1024,useBytes = TRUE)
-
+  suppressWarnings(readChar(fid,1024,useBytes = TRUE))
+  
   # Create data for results
   timeRes = seq(start, end, step)
   nr = length(timeRes) - 1
   timeRes = as.vector(timeRes[1:nr])
-  accelRes = matrix(0,nrow = nr, ncol = 3, dimnames = list(NULL, c("x", "y", "z")))
+  if (header$hardwareType == "AX3") {
+    accelRes = matrix(0,nrow = nr, ncol = 3, dimnames = list(NULL, c("x", "y", "z")))
+  } else if (header$hardwareType == "AX6") {
+    accelRes = matrix(0,nrow = nr, ncol = 6, dimnames = list(NULL, c("gx", "gy", "gz", "x", "y", "z")))
+  }
   temp = vector(mode = "double", nr)
   battery = vector(mode = "double", nr)
   light = vector(mode = "double", nr)
-
+  
   #############################################################################
   # Reading of data
-
+  
   # Create progress bar if it is necessary
   if (progressBar)
     pb = txtProgressBar(1, nr, style=3)
@@ -315,12 +401,17 @@ g.cwaread = function(fileName, start = 0, end = 0, progressBar = FALSE, desiredt
     return(invisible(list(header = header, data = NULL))) # <= list() inserted by VvH 23/4/2017
   }
   rawTime = vector(mode = "numeric", 300)
-  rawAccel = matrix(nrow = 300, ncol = 3)
+  if (header$hardwareType == "AX3") {
+    rawAccel = matrix(nrow = 300, ncol = 3)
+  } else {
+    rawAccel = matrix(nrow = 300, ncol = 6)
+  }
   rawPos = 1
   for (i in 2:numDBlocks) {
     raw = readDataBlock(fid)
-    if (is.null(raw))
+    if (is.null(raw)) {
       break
+    }
     # Save start and length of the previous block
     prevStart = prevRaw$start
     prevLength = prevRaw$length
@@ -331,7 +422,7 @@ g.cwaread = function(fileName, start = 0, end = 0, progressBar = FALSE, desiredt
     }
     # Create array of times
     time = seq(prevStart, raw$start, length.out = prevLength + 1)
-
+    
     # fill vector rawTime and matrix rawAccel for resampling
     if (rawPos == 1) {
       rawAccel[1,] = (prevRaw$data[1,])
@@ -343,7 +434,7 @@ g.cwaread = function(fileName, start = 0, end = 0, progressBar = FALSE, desiredt
     rawTime[rawPos:rawLast] = time[1:prevLength]
     rawAccel[rawPos:rawLast,] = as.matrix(prevRaw$data)
     lastTime = time[prevLength]
-
+    
     ###########################################################################
     # resampling of measurements
     last = pos+200;
@@ -355,7 +446,7 @@ g.cwaread = function(fileName, start = 0, end = 0, progressBar = FALSE, desiredt
     if (last>=pos) {
       accelRes[pos:last,] = tmp
     }
-
+    
     # Remove all rawdata exclude the last
     rawTime[1] = rawTime[rawLast]
     rawAccel[1,] = rawAccel[rawLast,]
@@ -397,7 +488,7 @@ g.cwaread = function(fileName, start = 0, end = 0, progressBar = FALSE, desiredt
     rawTime[rawPos:rawLast] = time[1:prevLength]
     rawAccel[rawPos:rawLast,] = as.matrix(prevRaw$data)
     lastTime = time[prevLength]
-
+    
     ###########################################################################
     # resampling of measurements
     last = pos+200;
@@ -440,6 +531,6 @@ g.cwaread = function(fileName, start = 0, end = 0, progressBar = FALSE, desiredt
   # Form outcome
   return(invisible(list(
     header = header,
-    data = as.data.frame(cbind(time = timeRes, accelRes, temp,  battery, light))
+    data = as.data.frame(cbind(time = timeRes, accelRes, temp,  battery, light), stringsAsFactors = TRUE)
   )))
 }
